@@ -109,16 +109,16 @@ static const unsigned short lin_data[] =
 bool
 module_african (RECODE_OUTER outer)
 {
-  return declare_explode_data (outer, ful_data, "AFRFUL-102-BPI_OCIL", NULL)
-    && declare_alias (outer, "bambara", "AFRFUL-102-BPI_OCIL")
-    && declare_alias (outer, "bra", "AFRFUL-102-BPI_OCIL")
-    && declare_alias (outer, "ewondo", "AFRFUL-102-BPI_OCIL")
-    && declare_alias (outer, "fulfulde", "AFRFUL-102-BPI_OCIL")
-    && declare_explode_data (outer, lin_data, "AFRLIN-104-BPI_OCIL", NULL)
-    && declare_alias (outer, "lingala", "AFRLIN-104-BPI_OCIL")
-    && declare_alias (outer, "lin", "AFRLIN-104-BPI_OCIL")
-    && declare_alias (outer, "sango", "AFRLIN-104-BPI_OCIL")
-    && declare_alias (outer, "wolof", "AFRLIN-104-BPI_OCIL");
+  return recode_declare_explode_data (outer, ful_data, "AFRFUL-102-BPI_OCIL", NULL)
+    && recode_declare_alias (outer, "bambara", "AFRFUL-102-BPI_OCIL")
+    && recode_declare_alias (outer, "bra", "AFRFUL-102-BPI_OCIL")
+    && recode_declare_alias (outer, "ewondo", "AFRFUL-102-BPI_OCIL")
+    && recode_declare_alias (outer, "fulfulde", "AFRFUL-102-BPI_OCIL")
+    && recode_declare_explode_data (outer, lin_data, "AFRLIN-104-BPI_OCIL", NULL)
+    && recode_declare_alias (outer, "lingala", "AFRLIN-104-BPI_OCIL")
+    && recode_declare_alias (outer, "lin", "AFRLIN-104-BPI_OCIL")
+    && recode_declare_alias (outer, "sango", "AFRLIN-104-BPI_OCIL")
+    && recode_declare_alias (outer, "wolof", "AFRLIN-104-BPI_OCIL");
 }
 
 void
