@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 2008-2018 Free Software Foundation, Inc.
+   Copyright © 2008-2023 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 2008.
 
    This library is free software; you can redistribute it and/or
@@ -22,20 +22,6 @@
 #ifndef CLEANER_H_
 # define CLEANER_H_
 
-# define clone_quoting_options librecode_clone_quoting_options
-# define code_to_ucs2 librecode_code_to_ucs2
-# define combine_byte_byte librecode_combine_byte_byte
-# define combine_byte_ucs2 librecode_combine_byte_ucs2
-# define combine_ucs2_byte librecode_combine_ucs2_byte
-# define combine_ucs2_ucs2 librecode_combine_ucs2_ucs2
-# define complete_pairs librecode_complete_pairs
-# define declare_alias librecode_declare_alias
-# define declare_explode_data librecode_declare_explode_data
-# define declare_iconv librecode_declare_iconv
-# define declare_implied_surface librecode_declare_implied_surface
-# define declare_single librecode_declare_single
-# define declare_strip_data librecode_declare_strip_data
-# define decode_known_pairs librecode_decode_known_pairs
 # define delmodule_african librecode_delmodule_african
 # define delmodule_afrtran librecode_delmodule_afrtran
 # define delmodule_applemac librecode_delmodule_applemac
@@ -70,25 +56,6 @@
 # define delmodule_utf8 librecode_delmodule_utf8
 # define delmodule_varia librecode_delmodule_varia
 # define delmodule_vietnamese librecode_delmodule_vietnamese
-# define edit_sequence librecode_edit_sequence
-# define explode_byte_byte librecode_explode_byte_byte
-# define explode_byte_ucs2 librecode_explode_byte_ucs2
-# define explode_ucs2_byte librecode_explode_ucs2_byte
-# define explode_ucs2_ucs2 librecode_explode_ucs2_ucs2
-# define find_alias librecode_find_alias
-# define find_and_report_subsets librecode_find_and_report_subsets
-# define get_byte librecode_get_byte
-# define put_byte librecode_put_byte
-# define get_quoting_style librecode_get_quoting_style
-# define get_ucs2 librecode_get_ucs2
-# define get_ucs4 librecode_get_ucs4
-# define init_combine librecode_init_combine
-# define init_explode librecode_init_explode
-# define init_ucs2_to_byte librecode_init_ucs2_to_byte
-# define invert_table librecode_invert_table
-# define list_all_symbols librecode_list_all_symbols
-# define list_concise_charset librecode_list_concise_charset
-# define list_full_charset librecode_list_full_charset
 # define module_african librecode_module_african
 # define module_afrtran librecode_module_afrtran
 # define module_applemac librecode_module_applemac
@@ -123,21 +90,6 @@
 # define module_utf8 librecode_module_utf8
 # define module_varia librecode_module_varia
 # define module_vietnamese librecode_module_vietnamese
-# define prepare_for_aliases librecode_prepare_for_aliases
-# define put_ucs2 librecode_put_ucs2
-# define put_ucs4 librecode_put_ucs4
-# define reversibility librecode_reversibility
-# define set_char_quoting librecode_set_char_quoting
-# define set_quoting_style librecode_set_quoting_style
-# define should_prefer_french librecode_should_prefer_french
 # define texte_latin1_diaeresis librecode_texte_latin1_diaeresis
-# define transform_byte_to_byte librecode_transform_byte_to_byte
-# define transform_byte_to_ucs2 librecode_transform_byte_to_ucs2
-# define transform_byte_to_variable librecode_transform_byte_to_variable
-# define transform_ucs2_to_byte librecode_transform_ucs2_to_byte
-# define transform_with_iconv librecode_transform_with_iconv
-# define ucs2_to_charname librecode_ucs2_to_charname
-# define ucs2_to_french_charname librecode_ucs2_to_french_charname
-# define ucs2_to_rfc1345 librecode_ucs2_to_rfc1345
 
 #endif /* ! CLEANER_H_ */
