@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1990, 93, 94, 96, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1990-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
@@ -17,7 +17,6 @@
    If not, see <https://www.gnu.org/licenses/>.
 */
 
-#include "config.h"
 #include "cleaner.h"
 
 #include <assert.h>
@@ -33,7 +32,6 @@
 #include "localcharset.h"
 #include "error.h"
 #include "gettext.h"
-#include "unused-parameter.h"
 
 #if ENABLE_NLS
 # define _(Text) gettext (Text)
@@ -57,10 +55,4 @@
 #define IS_ASCII(Character) \
   (!((Character) & ~BIT_MASK (7)))
 
-/* Debugging the memory allocator.  */
-#if WITH_DMALLOC
-# define DMALLOC_FUNC_CHECK
-# include <dmalloc.h>
-#endif
-
 #include "recodext.h"
