@@ -27,7 +27,7 @@ transform_ascii_flat (RECODE_SUBTASK subtask)
   int input_char;		/* current character */
   int temp_char;		/* look ahead character */
 
-  input_char = get_byte (subtask);
+  input_char = recode_get_byte (subtask);
   while (true)
     switch (input_char)
       {
@@ -36,12 +36,12 @@ transform_ascii_flat (RECODE_SUBTASK subtask)
 
       case '\n':
       case '\t':
-	put_byte (input_char, subtask);
-	input_char = get_byte (subtask);
+	recode_put_byte (input_char, subtask);
+	input_char = recode_get_byte (subtask);
 	break;
 
       case '\b':
-	input_char = get_byte (subtask);
+	input_char = recode_get_byte (subtask);
 	switch (input_char)
 	  {
 	  case '\'':
@@ -52,11 +52,11 @@ transform_ascii_flat (RECODE_SUBTASK subtask)
 	  case ',':
 	  case '_':
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
-	    input_char = get_byte (subtask);
+	    input_char = recode_get_byte (subtask);
 	    break;
 
 	  default:
-	    put_byte ('\b', subtask);
+	    recode_put_byte ('\b', subtask);
 	  }
 	break;
 
@@ -67,15 +67,15 @@ transform_ascii_flat (RECODE_SUBTASK subtask)
       case '~':
       case ',':
       case '_':
-	temp_char = get_byte (subtask);
+	temp_char = recode_get_byte (subtask);
 	if (temp_char == '\b')
 	  {
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
-	    input_char = get_byte (subtask);
+	    input_char = recode_get_byte (subtask);
 	  }
 	else
 	  {
-	    put_byte (input_char, subtask);
+	    recode_put_byte (input_char, subtask);
 	    input_char = temp_char;
 	  }
 	break;
@@ -84,25 +84,25 @@ transform_ascii_flat (RECODE_SUBTASK subtask)
 	if (!IS_ASCII (input_char))
 	  {
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
-	    put_byte ('M', subtask);
-	    put_byte ('-', subtask);
+	    recode_put_byte ('M', subtask);
+	    recode_put_byte ('-', subtask);
 	    input_char &= BIT_MASK (7);
 	  }
 	if (input_char < ' ' || input_char == BIT_MASK (7))
 	  {
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
-	    put_byte ('^', subtask);
+	    recode_put_byte ('^', subtask);
 	    input_char ^= (1 << 6);
 	  }
-	put_byte (input_char, subtask);
-	input_char = get_byte (subtask);
+	recode_put_byte (input_char, subtask);
+	input_char = recode_get_byte (subtask);
       }
 }
 
 bool
 module_flat (RECODE_OUTER outer)
 {
-  if (!declare_single (outer, "ASCII-BS", "flat",
+  if (!recode_declare_single (outer, "ASCII-BS", "flat",
 		       outer->quality_variable_to_variable,
 		       NULL, transform_ascii_flat))
     return false;
