@@ -29,10 +29,10 @@
 #define ENDLINE 30		/* end-line code for QNX */
 
 #define TRANSLATE_AND_BREAK(c2, c3) \
-  put_byte (ESCAPE, subtask);		\
-  put_byte (c2, subtask);		\
-  put_byte (c3, subtask);		\
-  input_char = get_byte (subtask);	\
+  recode_put_byte (ESCAPE, subtask);		\
+  recode_put_byte (c2, subtask);		\
+  recode_put_byte (c3, subtask);		\
+  input_char = recode_get_byte (subtask);	\
   break;
 
 static bool
@@ -40,7 +40,7 @@ transform_ibmpc_iconqnx (RECODE_SUBTASK subtask)
 {
   int input_char;
 
-  input_char = get_byte (subtask);
+  input_char = recode_get_byte (subtask);
   while (true)
     switch (input_char)
       {
@@ -68,14 +68,14 @@ transform_ibmpc_iconqnx (RECODE_SUBTASK subtask)
       case 128: TRANSLATE_AND_BREAK ('K', 'C');
 
       case DOS_CR:
-	input_char = get_byte (subtask);
+	input_char = recode_get_byte (subtask);
 	if (input_char == DOS_LF)
 	  {
-	    put_byte (ENDLINE, subtask);
-	    input_char = get_byte (subtask);
+	    recode_put_byte (ENDLINE, subtask);
+	    input_char = recode_get_byte (subtask);
 	  }
 	else
-	  put_byte (DOS_CR, subtask);
+	  recode_put_byte (DOS_CR, subtask);
 	break;
 
       case ENDLINE:
@@ -84,8 +84,8 @@ transform_ibmpc_iconqnx (RECODE_SUBTASK subtask)
 	FALLTHROUGH;
 
       default:
-	put_byte (input_char, subtask);
-	input_char = get_byte (subtask);
+	recode_put_byte (input_char, subtask);
+	input_char = recode_get_byte (subtask);
       }
 }
 
@@ -94,7 +94,7 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 {
   int input_char;		/* current character */
 
-  input_char = get_byte (subtask);
+  input_char = recode_get_byte (subtask);
   while (true)
     switch (input_char)
       {
@@ -102,24 +102,24 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 	SUBTASK_RETURN (subtask);
 
       case ENDLINE:
-	put_byte (DOS_CR, subtask);
-	put_byte (DOS_LF, subtask);
-	input_char = get_byte (subtask);
+	recode_put_byte (DOS_CR, subtask);
+	recode_put_byte (DOS_LF, subtask);
+	input_char = recode_get_byte (subtask);
 	break;
 
       case DOS_CR:
-	input_char = get_byte (subtask);
+	input_char = recode_get_byte (subtask);
 	if (input_char == DOS_LF)
 	  RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
-	put_byte (DOS_CR, subtask);
+	recode_put_byte (DOS_CR, subtask);
 	break;
 
       case ESCAPE:
-	input_char = get_byte (subtask);
+	input_char = recode_get_byte (subtask);
 	switch (input_char)
 	  {
 	  case 'A':
-	    input_char = get_byte (subtask);
+	    input_char = recode_get_byte (subtask);
 	    switch (input_char)
 	      {
 	      case 'a': input_char = 133; break;
@@ -128,15 +128,15 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 
 	      default:
 		RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-		put_byte (ESCAPE, subtask);
-		put_byte ('A', subtask);
+		recode_put_byte (ESCAPE, subtask);
+		recode_put_byte ('A', subtask);
 		if (input_char == EOF)
 		  SUBTASK_RETURN (subtask);
 	      }
 	    break;
 
 	  case 'B':
-	    input_char = get_byte (subtask);
+	    input_char = recode_get_byte (subtask);
 	    switch (input_char)
 	      {
 	      case 'e': input_char = 130; break;
@@ -144,15 +144,15 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 
 	      default:
 		RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-		put_byte (ESCAPE, subtask);
-		put_byte ('B', subtask);
+		recode_put_byte (ESCAPE, subtask);
+		recode_put_byte ('B', subtask);
 		if (input_char == EOF)
 		  SUBTASK_RETURN (subtask);
 	      }
 	    break;
 
 	  case 'C':
-	    input_char = get_byte (subtask);
+	    input_char = recode_get_byte (subtask);
 	    switch (input_char)
 	      {
 	      case 'a': input_char = 131; break;
@@ -163,15 +163,15 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 
 	      default:
 		RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-		put_byte (ESCAPE, subtask);
-		put_byte ('C', subtask);
+		recode_put_byte (ESCAPE, subtask);
+		recode_put_byte ('C', subtask);
 		if (input_char == EOF)
 		  SUBTASK_RETURN (subtask);
 	      }
 	    break;
 
 	  case 'H':
-	    input_char = get_byte (subtask);
+	    input_char = recode_get_byte (subtask);
 	    switch (input_char)
 	      {
 	      case 'e': input_char = 137; break;
@@ -180,15 +180,15 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 
 	      default:
 		RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-		put_byte (ESCAPE, subtask);
-		put_byte ('H', subtask);
+		recode_put_byte (ESCAPE, subtask);
+		recode_put_byte ('H', subtask);
 		if (input_char == EOF)
 		  SUBTASK_RETURN (subtask);
 	      }
 	    break;
 
 	  case 'K':
-	    input_char = get_byte (subtask);
+	    input_char = recode_get_byte (subtask);
 	    switch (input_char)
 	      {
 	      case 'c': input_char = 135; break;
@@ -196,8 +196,8 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 
 	      default:
 		RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-		put_byte (ESCAPE, subtask);
-		put_byte ('K', subtask);
+		recode_put_byte (ESCAPE, subtask);
+		recode_put_byte ('K', subtask);
 		if (input_char == EOF)
 		  SUBTASK_RETURN (subtask);
 	      }
@@ -205,15 +205,15 @@ transform_iconqnx_ibmpc (RECODE_SUBTASK subtask)
 
 	  default:
 	    RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-	    put_byte (ESCAPE, subtask);
+	    recode_put_byte (ESCAPE, subtask);
 	    if (input_char == EOF)
 	      SUBTASK_RETURN (subtask);
 	  }
 	FALLTHROUGH;
 
       default:
-	put_byte (input_char, subtask);
-	input_char = get_byte (subtask);
+	recode_put_byte (input_char, subtask);
+	input_char = recode_get_byte (subtask);
       }
 }
 
@@ -221,13 +221,13 @@ bool
 module_iconqnx (RECODE_OUTER outer)
 {
   return
-    declare_single (outer, "IBM-PC", "Icon-QNX",
+    recode_declare_single (outer, "IBM-PC", "Icon-QNX",
 		    outer->quality_variable_to_variable,
 		    NULL, transform_ibmpc_iconqnx)
-    && declare_single (outer, "Icon-QNX", "IBM-PC",
+    && recode_declare_single (outer, "Icon-QNX", "IBM-PC",
 		       outer->quality_variable_to_variable,
 		       NULL, transform_iconqnx_ibmpc)
-    && declare_alias (outer, "QNX", "Icon-QNX");
+    && recode_declare_alias (outer, "QNX", "Icon-QNX");
 }
 
 void
