@@ -25,7 +25,7 @@
    This macro is meant to be used only within the `while' loop in
    `transform_utf8_ucs[24]'.  */
 #define GET_DATA_BYTE \
-  character = get_byte (subtask);						\
+  character = recode_get_byte (subtask);						\
   if (character == EOF)							\
     {									\
       RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);		\
@@ -49,25 +49,25 @@ transform_ucs2_utf8 (RECODE_SUBTASK subtask)
 {
   unsigned value;
 
-  while (get_ucs2 (&value, subtask))
+  while (recode_get_ucs2 (&value, subtask))
     {
       if (value & ~BIT_MASK (7))
 	if (value & ~BIT_MASK (11))
 	  {
 	    /* 3 bytes - more than 11 bits, but not more than 16.  */
-	    put_byte ((BIT_MASK (3) << 5) | (BIT_MASK (6) & value >> 12), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
+	    recode_put_byte ((BIT_MASK (3) << 5) | (BIT_MASK (6) & value >> 12), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
 	  }
 	else
 	  {
 	    /* 2 bytes - more than 7 bits, but not more than 11.  */
-	    put_byte ((BIT_MASK (2) << 6) | (BIT_MASK (6) & value >> 6), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
+	    recode_put_byte ((BIT_MASK (2) << 6) | (BIT_MASK (6) & value >> 6), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
 	  }
       else
 	/* 1 byte - not more than 7 bits (that is, ASCII).  */
-	put_byte (value, subtask);
+	recode_put_byte (value, subtask);
     }
 
   SUBTASK_RETURN (subtask);
@@ -78,7 +78,7 @@ transform_ucs4_utf8 (RECODE_SUBTASK subtask)
 {
   unsigned value;
 
-  while (get_ucs4 (&value, subtask))
+  while (recode_get_ucs4 (&value, subtask))
     if (value & ~BIT_MASK (16))
       if (value & ~BIT_MASK (26))
 	if (value & ~BIT_MASK (31))
@@ -88,47 +88,47 @@ transform_ucs4_utf8 (RECODE_SUBTASK subtask)
   	else
 	  {
 	    /* 6 bytes - more than 26 bits, but not more than 31.  */
-	    put_byte ((BIT_MASK (6) << 2) | (BIT_MASK (6) & value >> 30), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value >> 24), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value >> 18), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value >> 12), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
-	    put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
+	    recode_put_byte ((BIT_MASK (6) << 2) | (BIT_MASK (6) & value >> 30), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 24), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 18), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 12), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
+	    recode_put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
 	  }
       else if (value & ~BIT_MASK (21))
 	{
 	  /* 5 bytes - more than 21 bits, but not more than 26.  */
-	  put_byte ((BIT_MASK (5) << 3) | (BIT_MASK (6) & value >> 24), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value >> 18), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value >> 12), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
+	  recode_put_byte ((BIT_MASK (5) << 3) | (BIT_MASK (6) & value >> 24), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 18), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 12), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
 	}
       else
 	{
 	  /* 4 bytes - more than 16 bits, but not more than 21.  */
-	  put_byte ((BIT_MASK (4) << 4) | (BIT_MASK (6) & value >> 18), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value >> 12), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
+	  recode_put_byte ((BIT_MASK (4) << 4) | (BIT_MASK (6) & value >> 18), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 12), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
 	}
     else if (value & ~BIT_MASK (7))
       if (value & ~BIT_MASK (11))
 	{
 	  /* 3 bytes - more than 11 bits, but not more than 16.  */
-	  put_byte ((BIT_MASK (3) << 5) | (BIT_MASK (6) & value >> 12), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
+	  recode_put_byte ((BIT_MASK (3) << 5) | (BIT_MASK (6) & value >> 12), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value >> 6), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
 	}
       else
 	{
 	  /* 2 bytes - more than 7 bits, but not more than 11.  */
-	  put_byte ((BIT_MASK (2) << 6) | (BIT_MASK (6) & value >> 6), subtask);
-	  put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
+	  recode_put_byte ((BIT_MASK (2) << 6) | (BIT_MASK (6) & value >> 6), subtask);
+	  recode_put_byte ((1 << 7) | (BIT_MASK (6) & value), subtask);
 	}
     else
       /* 1 byte - not more than 7 bits (that is, ASCII).  */
-      put_byte (value, subtask);
+      recode_put_byte (value, subtask);
 
   SUBTASK_RETURN (subtask);
 }
@@ -141,7 +141,7 @@ transform_ucs4_utf8 (RECODE_SUBTASK subtask)
 static bool
 transform_utf8_ucs4 (RECODE_SUBTASK subtask)
 {
-  int character = get_byte (subtask);
+  int character = recode_get_byte (subtask);
   unsigned value;
 
   while (character != EOF)
@@ -154,7 +154,7 @@ transform_utf8_ucs4 (RECODE_SUBTASK subtask)
 	  {
 	    /* 7 bytes - more than 31 bits (that is, exactly 32 :-).  */
 	    RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-	    character = get_byte (subtask);
+	    character = recode_get_byte (subtask);
 	  }
 	else
 	  {
@@ -165,8 +165,8 @@ transform_utf8_ucs4 (RECODE_SUBTASK subtask)
 	    GET_DATA_BYTE_AT (12);
 	    GET_DATA_BYTE_AT (6);
 	    GET_DATA_BYTE_AT (0);
-	    put_ucs4 (value, subtask);
-	    character = get_byte (subtask);
+	    recode_put_ucs4 (value, subtask);
+	    character = recode_get_byte (subtask);
 	  }
       else if ((character & BIT_MASK (5) << 3) == BIT_MASK (5) << 3)
 	{
@@ -176,8 +176,8 @@ transform_utf8_ucs4 (RECODE_SUBTASK subtask)
 	  GET_DATA_BYTE_AT (12);
 	  GET_DATA_BYTE_AT (6);
 	  GET_DATA_BYTE_AT (0);
-	  put_ucs4 (value, subtask);
-	  character = get_byte (subtask);
+	  recode_put_ucs4 (value, subtask);
+	  character = recode_get_byte (subtask);
 	}
       else
 	{
@@ -186,8 +186,8 @@ transform_utf8_ucs4 (RECODE_SUBTASK subtask)
 	  GET_DATA_BYTE_AT (12);
 	  GET_DATA_BYTE_AT (6);
 	  GET_DATA_BYTE_AT (0);
-	  put_ucs4 (value, subtask);
-	  character = get_byte (subtask);
+	  recode_put_ucs4 (value, subtask);
+	  character = recode_get_byte (subtask);
 	}
     else if ((character & BIT_MASK (2) << 6) == BIT_MASK (2) << 6)
       if ((character & BIT_MASK (3) << 5) == BIT_MASK (3) << 5)
@@ -196,28 +196,28 @@ transform_utf8_ucs4 (RECODE_SUBTASK subtask)
 	  value = (BIT_MASK (4) & character) << 12;
 	  GET_DATA_BYTE_AT (6);
 	  GET_DATA_BYTE_AT (0);
-	  put_ucs4 (value, subtask);
-	  character = get_byte (subtask);
+	  recode_put_ucs4 (value, subtask);
+	  character = recode_get_byte (subtask);
 	}
       else
 	{
 	  /* 2 bytes - more than 7 bits, but not more than 11.  */
 	  value = (BIT_MASK (5) & character) << 6;
 	  GET_DATA_BYTE_AT (0);
-	  put_ucs4 (value, subtask);
-	  character = get_byte (subtask);
+	  recode_put_ucs4 (value, subtask);
+	  character = recode_get_byte (subtask);
 	}
     else if ((character & 1 << 7) == 1 << 7)
       {
 	/* Valid only as a continuation byte.  */
 	RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
-	character = get_byte (subtask);
+	character = recode_get_byte (subtask);
       }
     else
       {
 	/* 1 byte - not more than 7 bits (that is, ASCII).  */
-	put_ucs4 (BIT_MASK (8) & character, subtask);
-	character = get_byte (subtask);
+	recode_put_ucs4 (BIT_MASK (8) & character, subtask);
+	character = recode_get_byte (subtask);
       }
 
   SUBTASK_RETURN (subtask);
@@ -227,21 +227,21 @@ bool
 module_utf8 (RECODE_OUTER outer)
 {
   return
-    declare_single (outer, "ISO-10646-UCS-4", "UTF-8",
+    recode_declare_single (outer, "ISO-10646-UCS-4", "UTF-8",
 		    outer->quality_variable_to_variable,
 		    NULL, transform_ucs4_utf8)
-    && declare_single (outer, "UTF-8", "ISO-10646-UCS-4",
+    && recode_declare_single (outer, "UTF-8", "ISO-10646-UCS-4",
 		       outer->quality_variable_to_variable,
 		       NULL, transform_utf8_ucs4)
 
-    && declare_alias (outer, "UTF-2", "UTF-8")
-    && declare_alias (outer, "UTF-FSS", "UTF-8")
-    && declare_alias (outer, "FSS_UTF", "UTF-8")
-    && declare_alias (outer, "TF-8", "UTF-8")
-    && declare_alias (outer, "u8", "UTF-8")
+    && recode_declare_alias (outer, "UTF-2", "UTF-8")
+    && recode_declare_alias (outer, "UTF-FSS", "UTF-8")
+    && recode_declare_alias (outer, "FSS_UTF", "UTF-8")
+    && recode_declare_alias (outer, "TF-8", "UTF-8")
+    && recode_declare_alias (outer, "u8", "UTF-8")
 
     /* Simple UCS-2 does not have to go through UTF-16.  */
-    && declare_single (outer, "ISO-10646-UCS-2", "UTF-8",
+    && recode_declare_single (outer, "ISO-10646-UCS-2", "UTF-8",
 		       outer->quality_variable_to_variable,
 		       NULL, transform_ucs2_utf8);
 }
